<h1 align="center">Akaneko</h1>
<h2 align="center"><a href="https://www.paypal.me/KawaiGirl1">Donate Me!</a></h2>
<h3 align="center">Functions</h3>
<h4>SFW - Safe For Work Functions</h4>
<h4>Usage : akaneko.neko()</h4>
<h5>neko             - Cute Anime SFW Picture</h5>
<h5>sfwfoxes         - Cute Fox Anime SFW Girl</h5>
<h5>wallpapers       - Anime SFW Wallpaper</h5>
<h5>mobilewallpapers - Anime Wallpaper For Mobile</h5>
<br><br>
<br><br>
<h4>NSFW - Not Safe For Work</h4>
<h4>Usage : akaneko.nsfw.bdsm()</h4>
<h5>bdsm             - Don't ask me what it is. Ask Google.</h5>
<h5>cum              - Don't Ask me</h5>
<h5>doujin           - Manga but NSFW Style</h5>
<h5>femdom           - Torture and Pleasure..?</h5>
<h5>hentai           - You already know it...</h5>
<h5>maid             - Anime Maid NSFW ( ͡° ͜ʖ ͡°)</h5>
<h5>orgy             - I Don't know about this ngl</h5>
<h5>panties          - Pantsu NSFW Pic ( ͡° ͜ʖ ͡°)</h5>
<h5>wallpaper        - NSFW Anime Wallpaper ( ͡° ͜ʖ ͡°)</h5>
<h5>mobilewallpapers - NSFW Mobile Anime Wallpapers ( ͡° ͜ʖ ͡°)</h5>
<h5>cuckhold         - Pleasure..?</h5>
<h5>netorare         - ^^^^^^^^^^^</h5>
<h5>gifs / gif       - NSFW Gifs ( ͡° ͜ʖ ͡°)</h5>
<h5>blowjob          - You already know what is this ( ͡° ͜ʖ ͡°)</h5>
<h5>feet             - ...</h5>
<h5>pussy			 - ...</h5>
<h5>uglyBastard      - UglyBastard NSFW Pic</h5>
<h5>uniform          - NSFW Uniform Pic ( ͡° ͜ʖ ͡°)</h5>
<h5>gangbang         - 3 or more Guy and 1 Girl ( ͡° ͜ʖ ͡°)</h5>
<h5>foxgirl          - NSFW Fox girl Pictures ( ͡° ͜ʖ ͡°)</h5>
<h5>cumslut          - NSFW Slut Picture ( ͡° ͜ʖ ͡°)</h5>
<h5>glasses          - NSFW Anime Glasses ( ͡° ͜ʖ ͡°)</h5>
<h5>thighs           - You already know what is this ( ͡° ͜ʖ ͡°)</h5>
<h5>tentacles        - ( ͡° ͜ʖ ͡°)</h5>
<h5>loli             - FBI OPEN UP!</h5>
<h5>masturbation     - ( ͡° ͜ʖ ͡°)</h5>
<h5>school           - ( ͡° ͜ʖ ͡°)</h5>
<h5>yuri             - Girls On top of eachother ( ͡° ͜ʖ ͡°)</h5>
<h5>zettaiRyouiki    - I Still don't understand Japanese, Soooo IDK</h5>